pub enum OnchainEffect {
RegisterContractWithConstructor(RegisterContractEffect),
RegisterContract(RegisterContractEffect),
DeleteContract(ContractName),
UpdateContractProgramId(ContractName, ProgramId),
UpdateTimeoutWindow(ContractName, TimeoutWindow),
}Expand description
Enum for various side-effects blobs can have on the chain. This is implemented as an enum for easier forward compatibility.
Variants
RegisterContractWithConstructor(RegisterContractEffect)
RegisterContractWithConstructor means that we expect the next blob from the contract to be a placeholder containing the constructor_metadata
RegisterContract(RegisterContractEffect)
RegisterContract means that we expect the contract’s next blob to be a real blob that will get proven
DeleteContract(ContractName)
UpdateContractProgramId(ContractName, ProgramId)
UpdateTimeoutWindow(ContractName, TimeoutWindow)