pub enum StakingAction {
Stake {
amount: u128,
},
Delegate {
validator: ValidatorPublicKey,
},
Distribute {
claim: RewardsClaim,
},
DepositForFees {
holder: ValidatorPublicKey,
amount: u128,
},
}Expand description
Enum representing the actions that can be performed by the Staking contract.
Variants
Stake
Delegate
Fields

validator: ValidatorPublicKeyDistribute
Fields

claim: RewardsClaimDepositForFees
Fees are deposited by the validators to be distributed to the bonded validators