pub enum TimeoutWindow {
NoTimeout,
Timeout {
hard_timeout: BlockHeight,
soft_timeout: BlockHeight,
},
}Variants
Implementations
Sourceimpl TimeoutWindow
Creates a new timeout window with hard and soft timeout block heights.
impl TimeoutWindow
Creates a new timeout window with hard and soft timeout block heights.
This function automatically ensures that hard_timeout <= soft_timeout by
swapping the parameters if they are provided in the wrong order. If the
hard_timeout is greater than soft_timeout, the values will be swapped
internally to maintain the invariant that hard timeout should occur before
or at the same time as the soft timeout.
Parameters
hard_timeout- The block height for the hard timeout (will be the earlier timeout)soft_timeout- The block height for the soft timeout (will be the later timeout)
Returns
A TimeoutWindow::Timeout variant with properly ordered timeout values.
pub fn timeout(hard_timeout: BlockHeight, soft_timeout: BlockHeight) -> Self