pub struct AggregateSignature {
pub signature: Signature,
pub validators: Vec<ValidatorPublicKey>,
}Fields
signature: Signaturevalidators: Vec<ValidatorPublicKey>Trait Implementations
Sourceimpl BorshDeserialize for AggregateSignature
impl BorshDeserialize for AggregateSignature
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AggregateSignature
impl BorshSerialize for AggregateSignature
Sourceimpl Clone for AggregateSignature
impl Clone for AggregateSignature
Sourcefn clone(&self) -> AggregateSignature
fn clone(&self) -> AggregateSignature
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AggregateSignature
impl Debug for AggregateSignature
Sourceimpl Default for AggregateSignature
impl Default for AggregateSignature
Sourcefn default() -> AggregateSignature
fn default() -> AggregateSignature
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AggregateSignature
impl<'de> Deserialize<'de> for AggregateSignature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for AggregateSignature
impl Hash for AggregateSignature
Sourceimpl Ord for AggregateSignature
impl Ord for AggregateSignature
Sourcefn cmp(&self, other: &AggregateSignature) -> Ordering
fn cmp(&self, other: &AggregateSignature) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AggregateSignature
impl PartialEq for AggregateSignature
Sourceimpl PartialOrd for AggregateSignature
impl PartialOrd for AggregateSignature
Sourceimpl Serialize for AggregateSignature
impl Serialize for AggregateSignature
impl Eq for AggregateSignature
impl StructuralPartialEq for AggregateSignature