pub struct Blob {
pub contract_name: ContractName,
pub data: BlobData,
}Expand description
A Blob is a binary-serialized action that the contract has to parse An action is often written as an enum representing the call of a specific contract function.
Fields
contract_name: ContractNamedata: BlobDataTrait Implementations
Sourceimpl BorshDeserialize for Blob
impl BorshDeserialize for Blob
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Blob
impl BorshSerialize for Blob
Sourceimpl<'de> Deserialize<'de> for Blob
impl<'de> Deserialize<'de> for Blob
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<Action: BorshSerialize> From<StructuredBlob<Action>> for Blob
impl<Action: BorshSerialize> From<StructuredBlob<Action>> for Blob
Sourcefn from(val: StructuredBlob<Action>) -> Self
fn from(val: StructuredBlob<Action>) -> Self
Converts to this type from the input type.
Sourceimpl<Action: BorshDeserialize> TryFrom<Blob> for StructuredBlob<Action>
impl<Action: BorshDeserialize> TryFrom<Blob> for StructuredBlob<Action>
impl Eq for Blob
impl StructuralPartialEq for Blob