pub struct BlobData(pub Vec<u8>);Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for BlobData
impl BorshDeserialize for BlobData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BlobData
impl BorshSerialize for BlobData
Sourceimpl<'de> Deserialize<'de> for BlobData
impl<'de> Deserialize<'de> for BlobData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<Action: BorshSerialize> From<StructuredBlobData<Action>> for BlobData
impl<Action: BorshSerialize> From<StructuredBlobData<Action>> for BlobData
Sourcefn from(val: StructuredBlobData<Action>) -> Self
fn from(val: StructuredBlobData<Action>) -> Self
Converts to this type from the input type.
Sourceimpl<Action: BorshDeserialize> TryFrom<BlobData> for StructuredBlobData<Action>
impl<Action: BorshDeserialize> TryFrom<BlobData> for StructuredBlobData<Action>
Sourceimpl TryFrom<BlobData> for StructuredBlobData<DropEndOfReader>
impl TryFrom<BlobData> for StructuredBlobData<DropEndOfReader>
impl Eq for BlobData
impl StructuralPartialEq for BlobData