pub struct BlockHeight(pub u64);Tuple Fields
0: u64Trait Implementations
Sourceimpl Add<BlockHeight> for u64
impl Add<BlockHeight> for u64
Sourcetype Output = BlockHeight
type Output = BlockHeight
The resulting type after applying the
+ operator.Sourcefn add(self, other: BlockHeight) -> BlockHeight
fn add(self, other: BlockHeight) -> BlockHeight
Performs the
+ operation. Read moreSourceimpl Add<u64> for BlockHeight
impl Add<u64> for BlockHeight
Sourcetype Output = BlockHeight
type Output = BlockHeight
The resulting type after applying the
+ operator.Sourceimpl Add for BlockHeight
impl Add for BlockHeight
Sourcetype Output = BlockHeight
type Output = BlockHeight
The resulting type after applying the
+ operator.Sourcefn add(self, other: BlockHeight) -> BlockHeight
fn add(self, other: BlockHeight) -> BlockHeight
Performs the
+ operation. Read moreSourceimpl BorshDeserialize for BlockHeight
impl BorshDeserialize for BlockHeight
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BlockHeight
impl BorshSerialize for BlockHeight
Sourceimpl Clone for BlockHeight
impl Clone for BlockHeight
Sourcefn clone(&self) -> BlockHeight
fn clone(&self) -> BlockHeight
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for BlockHeight
impl ComposeSchema for BlockHeight
Sourceimpl Debug for BlockHeight
impl Debug for BlockHeight
Sourceimpl Default for BlockHeight
impl Default for BlockHeight
Sourcefn default() -> BlockHeight
fn default() -> BlockHeight
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BlockHeight
impl<'de> Deserialize<'de> for BlockHeight
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for BlockHeight
impl Display for BlockHeight
Sourceimpl Hash for BlockHeight
impl Hash for BlockHeight
Sourceimpl Ord for BlockHeight
impl Ord for BlockHeight
Sourcefn cmp(&self, other: &BlockHeight) -> Ordering
fn cmp(&self, other: &BlockHeight) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BlockHeight
impl PartialEq for BlockHeight
Sourceimpl PartialOrd for BlockHeight
impl PartialOrd for BlockHeight
Sourceimpl Serialize for BlockHeight
impl Serialize for BlockHeight
Sourceimpl Sub<u64> for BlockHeight
impl Sub<u64> for BlockHeight
Sourcetype Output = BlockHeight
type Output = BlockHeight
The resulting type after applying the
- operator.Sourceimpl ToSchema for BlockHeight
impl ToSchema for BlockHeight
impl Copy for BlockHeight
impl Eq for BlockHeight
impl StructuralPartialEq for BlockHeight