pub struct BlockStakingData {
pub new_bounded_validators: Vec<ValidatorPublicKey>,
pub staking_actions: Vec<(Identity, StakingAction)>,
}Fields
new_bounded_validators: Vec<ValidatorPublicKey>staking_actions: Vec<(Identity, StakingAction)>Trait Implementations
Sourceimpl BorshDeserialize for BlockStakingData
impl BorshDeserialize for BlockStakingData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BlockStakingData
impl BorshSerialize for BlockStakingData
Sourceimpl Clone for BlockStakingData
impl Clone for BlockStakingData
Sourcefn clone(&self) -> BlockStakingData
fn clone(&self) -> BlockStakingData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockStakingData
impl Debug for BlockStakingData
Sourceimpl Default for BlockStakingData
impl Default for BlockStakingData
Sourcefn default() -> BlockStakingData
fn default() -> BlockStakingData
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BlockStakingData
impl<'de> Deserialize<'de> for BlockStakingData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more