pub struct ConsensusProposal {
pub slot: Slot,
pub parent_hash: ConsensusProposalHash,
pub cut: Cut,
pub staking_actions: Vec<ConsensusStakingAction>,
pub timestamp: TimestampMs,
}Fields
slot: Slotparent_hash: ConsensusProposalHashcut: Cutstaking_actions: Vec<ConsensusStakingAction>timestamp: TimestampMsTrait Implementations
Sourceimpl BorshDeserialize for ConsensusProposal
impl BorshDeserialize for ConsensusProposal
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ConsensusProposal
impl BorshSerialize for ConsensusProposal
Sourceimpl Clone for ConsensusProposal
impl Clone for ConsensusProposal
Sourcefn clone(&self) -> ConsensusProposal
fn clone(&self) -> ConsensusProposal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConsensusProposal
impl Debug for ConsensusProposal
Sourceimpl Default for ConsensusProposal
impl Default for ConsensusProposal
Sourcefn default() -> ConsensusProposal
fn default() -> ConsensusProposal
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConsensusProposal
impl<'de> Deserialize<'de> for ConsensusProposal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ConsensusProposal
impl Display for ConsensusProposal
Sourceimpl Hash for ConsensusProposal
impl Hash for ConsensusProposal
Sourceimpl Hashed<ConsensusProposalHash> for ConsensusProposal
This is the hash of the proposal, signed by validators
Any consensus-critical data should be hashed here.
impl Hashed<ConsensusProposalHash> for ConsensusProposal
This is the hash of the proposal, signed by validators Any consensus-critical data should be hashed here.
fn hashed(&self) -> ConsensusProposalHash
Sourceimpl Ord for ConsensusProposal
impl Ord for ConsensusProposal
Sourcefn cmp(&self, other: &ConsensusProposal) -> Ordering
fn cmp(&self, other: &ConsensusProposal) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ConsensusProposal
impl PartialEq for ConsensusProposal
Sourceimpl PartialOrd for ConsensusProposal
impl PartialOrd for ConsensusProposal
Sourceimpl Serialize for ConsensusProposal
impl Serialize for ConsensusProposal
impl Eq for ConsensusProposal
impl StructuralPartialEq for ConsensusProposal