pub struct Contract {
pub name: ContractName,
pub program_id: ProgramId,
pub state: StateCommitment,
pub verifier: Verifier,
pub timeout_window: TimeoutWindow,
}Fields
name: ContractNameprogram_id: ProgramIdstate: StateCommitmentverifier: Verifiertimeout_window: TimeoutWindowTrait Implementations
Sourceimpl BorshDeserialize for Contract
impl BorshDeserialize for Contract
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Contract
impl BorshSerialize for Contract
Sourceimpl<'de> Deserialize<'de> for Contract
impl<'de> Deserialize<'de> for Contract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Contract
impl StructuralPartialEq for Contract