pub struct DataProposal {
pub parent_data_proposal_hash: DataProposalParent,
pub txs: Vec<Transaction>,
/* private fields */
}Fields
parent_data_proposal_hash: DataProposalParenttxs: Vec<Transaction>Implementations
Sourceimpl DataProposal
impl DataProposal
pub fn new( parent_data_proposal_hash: DataProposalHash, txs: Vec<Transaction>, ) -> Self
pub fn new_root(lane_id: LaneId, txs: Vec<Transaction>) -> Self
pub fn remove_proofs(&mut self)
pub fn take_proofs(&mut self) -> Vec<(u64, ProofData)>
Sourcepub fn hydrate_proofs(&mut self, proofs: Vec<(u64, ProofData)>)
pub fn hydrate_proofs(&mut self, proofs: Vec<(u64, ProofData)>)
Proofs are kept as a vector because DP transactions are fundamentally ordered.
Sourcepub unsafe fn unsafe_set_hash(&mut self, hash: &DataProposalHash)
pub unsafe fn unsafe_set_hash(&mut self, hash: &DataProposalHash)
This is used to set the hash of the DataProposal when we can trust we know it (specifically - deserializating from local storage)
Safety
Marked unsafe so you think twice before using it, but this is safe rust-wise.