pub struct DropEndOfReader;Expand description
Struct used to be able to deserialize a StructuredBlobData
without knowing the concrete type of Action
warning: this will drop the end of the reader, thus, you can’t
deserialize a structure that contains a StructuredBlobData<DropEndOfReader>
Unless this struct is at the end of your data structure.
It’s not meant to be used outside the sdk internal logic.