pub struct LaneBytesSize(pub u64);Tuple Fields
0: u64Trait Implementations
Sourceimpl Add<usize> for LaneBytesSize
impl Add<usize> for LaneBytesSize
Sourceimpl BorshDeserialize for LaneBytesSize
impl BorshDeserialize for LaneBytesSize
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for LaneBytesSize
impl BorshSerialize for LaneBytesSize
Sourceimpl Clone for LaneBytesSize
impl Clone for LaneBytesSize
Sourcefn clone(&self) -> LaneBytesSize
fn clone(&self) -> LaneBytesSize
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for LaneBytesSize
impl ComposeSchema for LaneBytesSize
Sourceimpl Debug for LaneBytesSize
impl Debug for LaneBytesSize
Sourceimpl Default for LaneBytesSize
impl Default for LaneBytesSize
Sourcefn default() -> LaneBytesSize
fn default() -> LaneBytesSize
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LaneBytesSize
impl<'de> Deserialize<'de> for LaneBytesSize
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for LaneBytesSize
impl Display for LaneBytesSize
Sourceimpl Ord for LaneBytesSize
impl Ord for LaneBytesSize
Sourcefn cmp(&self, other: &LaneBytesSize) -> Ordering
fn cmp(&self, other: &LaneBytesSize) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LaneBytesSize
impl PartialEq for LaneBytesSize
Sourceimpl PartialOrd for LaneBytesSize
impl PartialOrd for LaneBytesSize
Sourceimpl Serialize for LaneBytesSize
impl Serialize for LaneBytesSize
Sourceimpl ToSchema for LaneBytesSize
impl ToSchema for LaneBytesSize
impl Copy for LaneBytesSize
impl Eq for LaneBytesSize
impl StructuralPartialEq for LaneBytesSize