pub struct NodeStateBlock {
pub signed_block: Arc<SignedBlock>,
pub staking_data: Arc<BlockStakingData>,
pub stateful_events: Arc<StatefulEvents>,
}Fields
signed_block: Arc<SignedBlock>staking_data: Arc<BlockStakingData>stateful_events: Arc<StatefulEvents>Trait Implementations
Sourceimpl BorshDeserialize for NodeStateBlock
impl BorshDeserialize for NodeStateBlock
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for NodeStateBlock
impl BorshSerialize for NodeStateBlock
Sourceimpl Clone for NodeStateBlock
impl Clone for NodeStateBlock
Sourcefn clone(&self) -> NodeStateBlock
fn clone(&self) -> NodeStateBlock
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeStateBlock
impl Debug for NodeStateBlock
Sourceimpl Default for NodeStateBlock
impl Default for NodeStateBlock
Sourcefn default() -> NodeStateBlock
fn default() -> NodeStateBlock
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NodeStateBlock
impl<'de> Deserialize<'de> for NodeStateBlock
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more