pub struct ProgramId(pub Vec<u8>);Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for ProgramId
impl BorshDeserialize for ProgramId
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ProgramId
impl BorshSerialize for ProgramId
Sourceimpl<'de> Deserialize<'de> for ProgramId
impl<'de> Deserialize<'de> for ProgramId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<NativeVerifiers> for ProgramId
impl From<NativeVerifiers> for ProgramId
Sourcefn from(value: NativeVerifiers) -> Self
fn from(value: NativeVerifiers) -> Self
Converts to this type from the input type.
impl Eq for ProgramId
impl StructuralPartialEq for ProgramId