pub struct Proof {
pub data: ProofData,
pub metadata: ProofMetadata,
}Fields
data: ProofDatametadata: ProofMetadataTrait Implementations
Sourceimpl BorshDeserialize for Proof
impl BorshDeserialize for Proof
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Proof
impl BorshSerialize for Proof
impl Eq for Proof
impl StructuralPartialEq for Proof