pub struct ProofData(pub Vec<u8>);Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for ProofData
impl BorshDeserialize for ProofData
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ProofData
impl BorshSerialize for ProofData
Sourceimpl<'de> Deserialize<'de> for ProofData
Available on crate feature full only.
impl<'de> Deserialize<'de> for ProofData
Available on crate feature
full only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hashed<ProofDataHash> for ProofData
Available on crate feature full only.
impl Hashed<ProofDataHash> for ProofData
Available on crate feature
full only.fn hashed(&self) -> ProofDataHash
impl Eq for ProofData
impl StructuralPartialEq for ProofData