pub struct Signed<T: BorshSerialize, V: BorshSerialize> {
pub msg: T,
pub signature: V,
}Fields
msg: Tsignature: VTrait Implementations
Sourceimpl<T, V> BorshDeserialize for Signed<T, V>
impl<T, V> BorshDeserialize for Signed<T, V>
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<T, V> BorshSerialize for Signed<T, V>
impl<T, V> BorshSerialize for Signed<T, V>
Sourceimpl<T: Clone + BorshSerialize, V: Clone + BorshSerialize> Clone for Signed<T, V>
impl<T: Clone + BorshSerialize, V: Clone + BorshSerialize> Clone for Signed<T, V>
Sourceimpl<'de, T, V> Deserialize<'de> for Signed<T, V>
impl<'de, T, V> Deserialize<'de> for Signed<T, V>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Signed<ValidatorCandidacy, ValidatorSignature>> for ConsensusStakingAction
impl From<Signed<ValidatorCandidacy, ValidatorSignature>> for ConsensusStakingAction
Sourcefn from(val: SignedByValidator<ValidatorCandidacy>) -> Self
fn from(val: SignedByValidator<ValidatorCandidacy>) -> Self
Converts to this type from the input type.
Sourceimpl<T: Hash + BorshSerialize, V: Hash + BorshSerialize> Hash for Signed<T, V>
impl<T: Hash + BorshSerialize, V: Hash + BorshSerialize> Hash for Signed<T, V>
Sourceimpl<T: Ord + BorshSerialize, V: Ord + BorshSerialize> Ord for Signed<T, V>
impl<T: Ord + BorshSerialize, V: Ord + BorshSerialize> Ord for Signed<T, V>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<T: PartialEq + BorshSerialize, V: PartialEq + BorshSerialize> PartialEq for Signed<T, V>
impl<T: PartialEq + BorshSerialize, V: PartialEq + BorshSerialize> PartialEq for Signed<T, V>
Sourceimpl<T: PartialOrd + BorshSerialize, V: PartialOrd + BorshSerialize> PartialOrd for Signed<T, V>
impl<T: PartialOrd + BorshSerialize, V: PartialOrd + BorshSerialize> PartialOrd for Signed<T, V>
impl<T: Eq + BorshSerialize, V: Eq + BorshSerialize> Eq for Signed<T, V>
impl<T: BorshSerialize, V: BorshSerialize> StructuralPartialEq for Signed<T, V>