pub struct StateCommitment(pub Vec<u8>);Expand description
State commitment of the contract.
Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for StateCommitment
impl BorshDeserialize for StateCommitment
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for StateCommitment
impl BorshSerialize for StateCommitment
Sourceimpl Clone for StateCommitment
impl Clone for StateCommitment
Sourcefn clone(&self) -> StateCommitment
fn clone(&self) -> StateCommitment
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for StateCommitment
impl ComposeSchema for StateCommitment
Sourceimpl Debug for StateCommitment
impl Debug for StateCommitment
Sourceimpl Default for StateCommitment
impl Default for StateCommitment
Sourcefn default() -> StateCommitment
fn default() -> StateCommitment
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StateCommitment
impl<'de> Deserialize<'de> for StateCommitment
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for StateCommitment
impl Hash for StateCommitment
Sourceimpl PartialEq for StateCommitment
impl PartialEq for StateCommitment
Sourceimpl Serialize for StateCommitment
impl Serialize for StateCommitment
Sourceimpl ToSchema for StateCommitment
impl ToSchema for StateCommitment
impl Eq for StateCommitment
impl StructuralPartialEq for StateCommitment