pub struct StatefulEvents {
pub events: Vec<(TxId, StatefulEvent)>,
}Fields
events: Vec<(TxId, StatefulEvent)>Trait Implementations
Sourceimpl BorshDeserialize for StatefulEvents
impl BorshDeserialize for StatefulEvents
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for StatefulEvents
impl BorshSerialize for StatefulEvents
Sourceimpl Clone for StatefulEvents
impl Clone for StatefulEvents
Sourcefn clone(&self) -> StatefulEvents
fn clone(&self) -> StatefulEvents
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatefulEvents
impl Debug for StatefulEvents
Sourceimpl Default for StatefulEvents
impl Default for StatefulEvents
Sourcefn default() -> StatefulEvents
fn default() -> StatefulEvents
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StatefulEvents
impl<'de> Deserialize<'de> for StatefulEvents
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more