pub struct StructuredBlob<Action> {
pub contract_name: ContractName,
pub data: StructuredBlobData<Action>,
}Fields
contract_name: ContractNamedata: StructuredBlobData<Action>Trait Implementations
Sourceimpl<Action> BorshDeserialize for StructuredBlob<Action>where
Action: BorshDeserialize,
impl<Action> BorshDeserialize for StructuredBlob<Action>where
Action: BorshDeserialize,
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<Action> BorshSerialize for StructuredBlob<Action>where
Action: BorshSerialize,
impl<Action> BorshSerialize for StructuredBlob<Action>where
Action: BorshSerialize,
Sourceimpl<Action: Debug> Debug for StructuredBlob<Action>
impl<Action: Debug> Debug for StructuredBlob<Action>
Sourceimpl<Action: BorshSerialize> From<StructuredBlob<Action>> for Blob
impl<Action: BorshSerialize> From<StructuredBlob<Action>> for Blob
Sourcefn from(val: StructuredBlob<Action>) -> Self
fn from(val: StructuredBlob<Action>) -> Self
Converts to this type from the input type.