pub struct ValidatorSignature {
pub signature: Signature,
pub validator: ValidatorPublicKey,
}Fields
signature: Signaturevalidator: ValidatorPublicKeyTrait Implementations
Sourceimpl BorshDeserialize for ValidatorSignature
impl BorshDeserialize for ValidatorSignature
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ValidatorSignature
impl BorshSerialize for ValidatorSignature
Sourceimpl Clone for ValidatorSignature
impl Clone for ValidatorSignature
Sourcefn clone(&self) -> ValidatorSignature
fn clone(&self) -> ValidatorSignature
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidatorSignature
impl Debug for ValidatorSignature
Sourceimpl<'de> Deserialize<'de> for ValidatorSignature
impl<'de> Deserialize<'de> for ValidatorSignature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ValidatorSignature
impl Hash for ValidatorSignature
Sourceimpl Ord for ValidatorSignature
impl Ord for ValidatorSignature
Sourcefn cmp(&self, other: &ValidatorSignature) -> Ordering
fn cmp(&self, other: &ValidatorSignature) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ValidatorSignature
impl PartialEq for ValidatorSignature
Sourceimpl PartialOrd for ValidatorSignature
impl PartialOrd for ValidatorSignature
Sourceimpl Serialize for ValidatorSignature
impl Serialize for ValidatorSignature
impl Eq for ValidatorSignature
impl StructuralPartialEq for ValidatorSignature