pub struct Calldata {
pub tx_hash: TxHash,
pub identity: Identity,
pub blobs: IndexedBlobs,
pub tx_blob_count: usize,
pub index: BlobIndex,
pub tx_ctx: Option<TxContext>,
pub private_input: Vec<u8>,
}Expand description
This struct is passed from the application backend to the contract as an input. It contains the data that the contract will use to run the blob’s action on its state.
Fields
tx_hash: TxHashTxHash of the BlobTransaction being proved
identity: IdentityUser’s identity used for the BlobTransaction
blobs: IndexedBlobsSubset of Blobs of the BlobTransaction
tx_blob_count: usizeNumber of ALL blobs in the transaction. tx_blob_count >= blobs.len()
index: BlobIndexIndex of the blob corresponding to the contract. The Blob referenced by this index has to be parsed by the contract
tx_ctx: Option<TxContext>Optional additional context of the BlobTransaction
private_input: Vec<u8>Additional input for the contract that is not written on-chain in the BlobTransaction
Implementations